Mixture Reducers
================

.. automodule:: stonesoup.mixturereducer
    :no-members:

.. automodule:: stonesoup.mixturereducer.base
    :show-inheritance:

.. automodule:: stonesoup.mixturereducer.gaussianmixture
    :show-inheritance:
